==> tsta-0.0.1.4-py3-none-any.whl: src/modules.py <==
global_testa_config = {
    "ta-rb": {
        "outputMethod": "puts",
        "commentStartBy": "#",
        "tryCatch": "\nbegin\n\t ****rescue \n\tputs(es) \nend",
        "function": "def ",
        "varDeclaration": "",
        "classInstantiationNew": "",
        "AccoladeStart": "",
        "AccoladeEnd": "\n\tend",
        "NoneNull": "None",
        "selfOrThis": "self",
        "selfOnFunctionParams": True,
        "semicolon": "",
        "scriptStarter": "",
        "scriptEnd": "",
        "prefixVariable": ""
    },
    "ta-py": {
        "outputMethod": "print",
        "commentStartBy": "#",
        "tryCatch": "\ntry: \n\t ****except Exception as es: \n\t print(str(es))\n",
        "function": "def ",
        "varDeclaration": "",
        "classInstantiationNew": "",
        "AccoladeStart": ":",
        "AccoladeEnd": "",
        "NoneNull": "None",
        "selfOrThis": "self",
        "selfOnFunctionParams": True,
        "semicolon": "",
        "scriptStarter": "",
        "scriptEnd": "",
        "prefixVariable": ""
    },
    "ta-php": {
        "outputMethod": "print",
        "commentStartBy": "//",
        "tryCatch": "\ntry{ \n\t ****}catch(Exception $e){ \n\t print($e);}",
        "function": "function ",
        "varDeclaration": "$",
        "classInstantiationNew": "new ",
        "AccoladeStart": "{",
        "AccoladeEnd": "}",
        "NoneNull": "null",
        "selfOrThis": "$this",
        "selfOnFunctionParams": False,
        "semicolon": ";",
        "scriptStarter": "<?php \n",
        "scriptEnd": "\n ?>",
        "prefixVariable": "$"
    },
    "ta-js": {
        "outputMethod": "console.log",
        "commentStartBy": "//",
        "tryCatch": "}\ntry{ \n\t ****}catch(err){ \n\t console.log(es);}",
        "function": " ",
        "varDeclaration": "var ",
        "classInstantiationNew": "new ",
        "AccoladeStart": "{",
        "AccoladeEnd": "}",
        "NoneNull": "null",
        "selfOrThis": "this",
        "selfOnFunctionParams": False,
        "semicolon": ";",
        "scriptStarter": "",
        "scriptEnd": "",
        "prefixVariable": ""
    }
}

==> tsta-0.0.1.6-py3-none-any.whl: src/modules.py <==
global_testa_config = {
    "ta-rb": {
        "outputMethod": "puts",
        "commentStartBy": "#",
        "tryCatch": "\nbegin\n\t ****rescue \n\tputs(es) \nend",
        "function": "def ",
        "varDeclaration": "",
        "classInstantiationNew": "",
        "AccoladeStart": "",
        "AccoladeEnd": "\n\tend",
        "NoneNull": "None",
        "selfOrThis": "self",
        "selfOnFunctionParams": True,
        "semicolon": "",
        "scriptStarter": "",
        "scriptEnd": "",
        "prefixVariable": "",
    },
    "ta-py": {
        "outputMethod": "print",
        "commentStartBy": "#",
        "tryCatch": "\ntry: \n\t ****except Exception as es: \n\t print(str(es))\n",
        "function": "def ",
        "varDeclaration": "",
        "classInstantiationNew": "",
        "AccoladeStart": ":",
        "AccoladeEnd": "",
        "NoneNull": "None",
        "selfOrThis": "self",
        "selfOnFunctionParams": True,
        "semicolon": "",
        "scriptStarter": "",
        "scriptEnd": "",
        "prefixVariable": "",
    },
    "ta-php": {
        "outputMethod": "print",
        "commentStartBy": "//",
        "tryCatch": "\ntry{ \n\t ****}catch(Exception $e){ \n\t print($e);}",
        "function": "function ",
        "varDeclaration": "$",
        "classInstantiationNew": "new ",
        "AccoladeStart": "{",
        "AccoladeEnd": "}",
        "NoneNull": "null",
        "selfOrThis": "$this",
        "selfOnFunctionParams": False,
        "semicolon": ";",
        "scriptStarter": "<?php \n",
        "scriptEnd": "\n ?>",
        "prefixVariable": "$",
    },
    "ta-js": {
        "outputMethod": "console.log",
        "commentStartBy": "//",
        "tryCatch": "}\ntry{ \n\t ****}catch(err){ \n\t console.log(es);}",
        "function": " ",
        "varDeclaration": "var ",
        "classInstantiationNew": "new ",
        "AccoladeStart": "{",
        "AccoladeEnd": "}",
        "NoneNull": "null",
        "selfOrThis": "this",
        "selfOnFunctionParams": False,
        "semicolon": ";",
        "scriptStarter": "",
        "scriptEnd": "",
        "prefixVariable": "",
    },
}
